@@ -41,7 +41,7 @@ except ImportError:
 
     NATIVE_SD = False
 
-__version__ = "6.2.5"
+__version__ = "6.2.6"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_PyPortal.git"
 
 
@@ -138,7 +138,10 @@ class Peripherals:
         if self._backlight:
             self._backlight.duty_cycle = int(val * 65535)
         else:
-            self._display.auto_brightness = False
+            try:
+                self._display.auto_brightness = False
+            except AttributeError:
+                pass
             self._display.brightness = val
 
     def play_file(self, file_name, wait_to_finish=True):
